pub struct ModelSource { /* private fields */ }Expand description
Source for loading a model from disk or HuggingFace.
Implementations
Sourceimpl ModelSource
impl ModelSource
Sourcepub fn from_file(path: impl Into<PathBuf>) -> Self
pub fn from_file(path: impl Into<PathBuf>) -> Self
Create a source backed by a local model file.
Sourcepub fn from_hf(repo_id: impl Into<String>, filename: impl Into<String>) -> Self
pub fn from_hf(repo_id: impl Into<String>, filename: impl Into<String>) -> Self
Create a source backed by a HuggingFace repo + filename.
Sourcepub fn from_hf_dir(
repo_id: impl Into<String>,
directory: impl Into<String>,
) -> Self
pub fn from_hf_dir( repo_id: impl Into<String>, directory: impl Into<String>, ) -> Self
Create a source backed by a HuggingFace repo + directory prefix.
Sourcepub fn with_revision(self, revision: impl Into<String>) -> Self
pub fn with_revision(self, revision: impl Into<String>) -> Self
Set the HuggingFace revision (branch, tag, or commit SHA).
Sourcepub fn resolve(&self) -> Result<PathBuf, ModelSourceError>
pub fn resolve(&self) -> Result<PathBuf, ModelSourceError>
Resolve the model path, downloading if necessary.
Sourcepub fn local_path(&self) -> Option<&Path>
pub fn local_path(&self) -> Option<&Path>
Return the local path when the source is a file.